@@ -143,7 +143,7 @@ typedef struct nv_ioctl_rm_api_old_version
 
 typedef enum {
     NV_CPU_TYPE_UNKNOWN = 0,
-    NV_CPU_TYPE_ARM_A9
+    NV_CPU_TYPE_ARM_A15
 } nv_cpu_type_t;
 
 /* alloc event */
@@ -173,10 +173,6 @@ typedef struct nv_ioctl_free_os_event
     (((domain) == NV_CTL_DEVICE_PCI_DOMAIN) && \
      ((bus) == NV_CTL_DEVICE_PCI_BUS) && ((slot) == NV_CTL_DEVICE_PCI_SLOT))
 
-#define NV_PCI_DEV_FMT          "%04x:%02x:%02x.%x"
-#define NV_PCI_DEV_FMT_ARGS(nv) (nv)->pci_info.domain, (nv)->pci_info.bus, \
-                                (nv)->pci_info.slot, (nv)->pci_info.function
-
 /* status code */
 typedef struct nv_ioctl_status_code
 {
@@ -227,7 +223,7 @@ typedef union
 #define NVRM_PCICFG_BAR_MEMTYPE_64BIT   0x00000004
 #define NVRM_PCICFG_BAR_ADDR_MASK       0xfffffff0
 
-#define NVRM_PCICFG_NUM_DWORDS          16
+#define NVRM_PCICFG_NUM_DWORDS          64
 
 #define NV_GPU_NUM_BARS                 3
 #define NV_GPU_BAR_INDEX_REGS           0
@@ -335,7 +331,7 @@ typedef struct
 
     NvU32  interrupt_line;
 
-    NvBool primary_vga;
+    NvU32 primary_vga;
 
     NvU32 sim_env;
 
@@ -347,10 +343,7 @@ typedef struct
     nv_kern_mapping_t *kern_mappings;
 
     nv_mmap_context_t *mmap_contexts;
- 
-    /* DMA addressable range of the device */
-    NvU64 dma_addressable_start;
-    NvU64 dma_addressable_limit;
+
 } nv_state_t;
 
 // Forward define the gpu ops structures
@@ -453,6 +446,8 @@ typedef struct
 #define NV_I2C_CMD_SMBUS_WRITE       4
 #define NV_I2C_CMD_SMBUS_QUICK_WRITE 5
 #define NV_I2C_CMD_SMBUS_QUICK_READ  6
+#define NV_I2C_CMD_SMBUS_BLOCK_READ  7
+#define NV_I2C_CMD_SMBUS_BLOCK_WRITE 8
 
 /*
 ** where we hide our nv_state_t * ...
@@ -461,10 +456,6 @@ typedef struct
 #define NV_GET_NV_STATE(pGpu) \
     (nv_state_t *)((pGpu) ? (pGpu)->pOsHwInfo : NULL)
 
-#define IS_DMA_ADDRESSABLE(nv, offset)                                          \
-    (((offset) >= (nv)->dma_addressable_start) &&                               \
-     ((offset) <= (nv)->dma_addressable_limit))
-
 #define IS_REG_OFFSET(nv, offset, length)                                       \
     (((offset) >= (nv)->regs->cpu_address) &&                                   \
     (((offset) + ((length)-1)) <=                                               \
@@ -614,8 +605,6 @@ RM_STATUS  NV_API_CALL  nv_nvmap_release_pages   (nv_state_t *, NvU64, NvU64 *,
 #endif
 RM_STATUS  NV_API_CALL  nv_alloc_os_descriptor_handle (nv_state_t *, NvS32, void *, NvU64, NvU32 *);
 NvU64      NV_API_CALL  nv_get_dma_start_address (nv_state_t *);
-void       NV_API_CALL  nv_pci_trigger_recovery  (nv_state_t *);
-RM_STATUS  NV_API_CALL  nv_set_primary_vga_status(nv_state_t *);
 
 #if defined(NVCPU_X86) || defined(NVCPU_X86_64)
 NvBool     NV_API_CALL  nv_is_virtualized_system  (nv_stack_t *);
@@ -692,7 +681,6 @@ RM_STATUS  NV_API_CALL  rm_p2p_destroy_mapping    (nv_stack_t *, NvU64);
 RM_STATUS  NV_API_CALL  rm_p2p_get_pages          (nv_stack_t *, NvU64, NvU32, NvU64, NvU64, NvU64 **, NvU32 **, NvU32 **, NvU32 *, void *, void (*)(void *), void *);
 RM_STATUS  NV_API_CALL  rm_p2p_put_pages          (nv_stack_t *, NvU64, NvU32, NvU64, void *);
 RM_STATUS  NV_API_CALL  rm_get_cpu_type           (nv_stack_t *, nv_cpu_type_t *);
-RM_STATUS  NV_API_CALL  rm_get_gpu_debug_data     (nv_stack_t *, nv_state_t *, void *, NvU32 *);
 
 RM_STATUS  NV_API_CALL  rm_gpu_ops_create_session (nv_stack_t *, nvgpuSessionHandle_t *);
 RM_STATUS  NV_API_CALL  rm_gpu_ops_destroy_session (nv_stack_t *, nvgpuSessionHandle_t);
