@@ -1458,7 +1458,7 @@ RM_STATUS NV_API_CALL nv_dma_map_pages(
     nv_state_t *nv,
     NvU64       page_count,
     NvU64      *pte_array,
-    void       *page_array
+    void      **priv
 )
 {
     return RM_ERR_NOT_SUPPORTED;
@@ -1467,7 +1467,8 @@ RM_STATUS NV_API_CALL nv_dma_map_pages(
 RM_STATUS NV_API_CALL nv_dma_unmap_pages(
     nv_state_t *nv,
     NvU64       page_count,
-    NvU64      *pte_array
+    NvU64      *pte_array,
+    void      **priv
 )
 {
     return RM_ERR_NOT_SUPPORTED;
