@@ -117,7 +117,9 @@ typedef signed int         NvS32; /* -2147483648 to 2147483647               */
 #endif
 
 /* 64-bit types for compilers that support them, plus some obsolete variants */
-#if defined(__GNUC__) || defined(__arm) || defined(__IAR_SYSTEMS_ICC__) || defined(__ghs__) || defined(_WIN64) || defined(__SUNPRO_C) || defined(__SUNPRO_CC)
+#if defined(__GNUC__) || defined(__arm) || defined(__IAR_SYSTEMS_ICC__) || \
+    defined(__ghs__) || defined(_WIN64) || defined(__SUNPRO_C) || \
+    defined(__SUNPRO_CC) || defined (__xlC__)
 typedef unsigned long long NvU64; /* 0 to 18446744073709551615          */
 typedef          long long NvS64; /* 2^-63 to 2^63-1                    */
 #else
@@ -430,12 +432,13 @@ typedef NvU64                                                      NvUFXP48_16;
 #define NV_TYPES_FXP_FRACTIONAL_MSB(x, y)                       ((y)-1):((y)-1)
 #define NV_TYPES_FXP_FRACTIONAL_MSB_ONE                              0x00000001
 #define NV_TYPES_FXP_FRACTIONAL_MSB_ZERO                             0x00000000
+#define NV_TYPES_FXP_ZERO                                                   (0)
+
 /*!
  * - UNSIGNED - These are only used for unsigned.
  */
-#define NV_TYPES_UFXP_INTEGER_MAX(x, y)                         (~(BIT((x))-1))
+#define NV_TYPES_UFXP_INTEGER_MAX(x, y)                         (~(BIT((y))-1))
 #define NV_TYPES_UFXP_INTEGER_MIN(x, y)                                     (0)
-#define NV_TYPES_UFXP_ZERO                                                    0
 
 /*!
  * - SIGNED - These are only used for signed.
@@ -448,7 +451,6 @@ typedef NvU64                                                      NvUFXP48_16;
 #define NV_TYPES_SFXP_S32_SIGN_EXTENSION_NEGATIVE(x, y)         (BIT(32-(x))-1)
 #define NV_TYPES_SFXP_INTEGER_MAX(x, y)                            (BIT((x))-1)
 #define NV_TYPES_SFXP_INTEGER_MIN(x, y)                         (~(BIT((x))-1))
-#define NV_TYPES_SFXP_ZERO                                                    0
 
 /*!
  * Conversion macros used for converting between integer and fixed point
@@ -476,10 +478,12 @@ typedef NvU64                                                      NvUFXP48_16;
                         DRF_SHIFT(NV_TYPES_FXP_INTEGER((x), (y)))))
 
 #define NV_TYPES_U32_TO_UFXP_X_Y_SCALED(x, y, integer, scale)                 \
-    ((NvUFXP##x##_##y) (((((NvU32) (integer)) <<                              \
-                             DRF_SHIFT(NV_TYPES_FXP_INTEGER((x), (y)))) +     \
-                         ((scale) / 2)) /                                     \
-                        (scale)))
+    ((NvUFXP##x##_##y) ((((((NvU32) (integer)) <<                             \
+                        DRF_SHIFT(NV_TYPES_FXP_INTEGER((x), (y))))) /         \
+                            (scale)) +                                        \
+                        ((((((NvU32) (integer)) <<                            \
+                            DRF_SHIFT(NV_TYPES_FXP_INTEGER((x), (y)))) %      \
+                                (scale)) > ((scale) / 2)) ? 1 : 0)))
 
 #define NV_TYPES_UFXP_X_Y_TO_U32(x, y, fxp)                                   \
     ((NvU32) (DRF_VAL(_TYPES, _FXP, _INTEGER((x), (y)),                       \
