@@ -97,7 +97,7 @@ RM_STATUS   NV_API_CALL  os_pci_read_dword           (void *, NvU32, NvU32 *);
 RM_STATUS   NV_API_CALL  os_pci_write_byte           (void *, NvU32, NvU8);
 RM_STATUS   NV_API_CALL  os_pci_write_word           (void *, NvU32, NvU16);
 RM_STATUS   NV_API_CALL  os_pci_write_dword          (void *, NvU32, NvU32);
-void*       NV_API_CALL  os_map_kernel_space         (NvU64, NvU64, NvU32, NvU32);
+void*       NV_API_CALL  os_map_kernel_space         (NvU64, NvU64, NvU32);
 void        NV_API_CALL  os_unmap_kernel_space       (void *, NvU64);
 void*       NV_API_CALL  os_map_user_space           (NvU64, NvU64, NvU32, NvU32, void **);
 void        NV_API_CALL  os_unmap_user_space         (void *, NvU64, void *);
@@ -194,8 +194,6 @@ void NV_API_CALL  nv_prints(NvU32 debuglevel, const char *string);
 // #define NV_MEMORY_TYPE_AGP          1
 #define NV_MEMORY_TYPE_REGISTERS    2
 #define NV_MEMORY_TYPE_FRAMEBUFFER  3
-#define NV_MEMORY_TYPE_INSTANCE     4
-#define NV_MEMORY_TYPE_DEVICE_MMIO  5  /*  All kinds of MMIO referred by NVRM e.g. BARs and MCFG of device */
 
 #define NV_MEMORY_NONCONTIGUOUS     0
 #define NV_MEMORY_CONTIGUOUS        1
@@ -208,6 +206,7 @@ void NV_API_CALL  nv_prints(NvU32 debuglevel, const char *string);
 #define NV_MEMORY_WRITEBACK         5
 #define NV_MEMORY_DEFAULT           6
 #define NV_MEMORY_UNCACHED_WEAK     7
+#define NV_MEMORY_UNCACHED_DEVICE   8
 
 #define NV_PROTECT_READABLE   1
 #define NV_PROTECT_WRITEABLE  2
