@@ -149,7 +149,7 @@ typedef NvU32 RM_STATUS;
 #define RM_ERR_IRQ_NOT_FIRING           0x0000002B
 #define RM_ERR_MULTIPLE_MEMORY_TYPES    0x0000002C
 #define RM_ERR_NO_FREE_FIFOS            0x0000002D
-#define RM_ERR_NO_FREE_MEM              0x0000002E
+#define RM_ERR_NO_MEMORY                0x0000002E
 #define RM_ERR_NOT_SUPPORTED            0x0000002F
 #define RM_ERR_OBJECT_NOT_FOUND         0x00000030
 #define RM_ERR_OBJECT_TYPE_MISMATCH     0x00000031
@@ -191,7 +191,7 @@ typedef NvU32 RM_STATUS;
 #define RM_ERR_CONSTRAINT_VIOLATION     0x00000065
 #define RM_ERR_CYCLE_DETECTED           0x00000066
 #define RM_ERR_MISMATCHED_SLAVE         0x00000067
-#define RM_ERR_NO_MEMORY                0x00000068
+
 #define RM_ERR_MORE_DATA_AVAILABLE      0x00000069
 #define RM_ERR_MODULE_LOAD_FAILED       0x0000006A
 #define RM_ERR_OVERLAPPING_UVM_COMMIT   0x0000006B
@@ -200,6 +200,8 @@ typedef NvU32 RM_STATUS;
 #define RM_ERR_ECC_ERROR                0x0000006E
 #define RM_ERR_RC_ERROR                 0x0000006F
 #define RM_ERR_SIGNAL_PENDING           0x00000070
+#define RM_ERR_PID_NOT_FOUND            0x00000071
+#define RM_ERR_GPU_UUID_NOT_FOUND       0x00000072
 
 // Warnings:
 #define RM_WARN_NULL_OBJECT                 0x00000100
